import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Directive, Self, Optional, SkipSelf, Inject, Input, ContentChildren, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import * as i1 from '@angular/forms';
import { Validators as Validators$1, NG_VALIDATORS } from '@angular/forms';

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
const VALIDATE_ELEMENT = new InjectionToken('Validate element');
// eslint-disable-next-line @angular-eslint/use-injectable-provided-in
class AbstractValidateElementDirective {
    constructor() {
        this.errorMessages = [];
        this.isGroup = false;
    }
    // eslint-disable-next-line @angular-eslint/contextual-lifecycle
    ngOnInit() {
        if ('validity' in this.elementRef.nativeElement) {
            this.ngControl.control.__elementValidity
                = this.elementRef.nativeElement.validity;
        }
        if (!this.feedbackElementContainer && this.elementRef.nativeElement.classList.contains('form-group')) {
            this.feedbackElementContainer = this.elementRef.nativeElement;
        }
    }
    // eslint-disable-next-line @angular-eslint/contextual-lifecycle
    ngAfterViewChecked() {
        var _a, _b;
        if (!this.ngFormValidate) {
            return;
        }
        if (!this.isGroup && this.ngControl.dirty && (!this.config.displayOnTouched || this.ngControl.touched)) {
            (_a = (this.feedbackElementContainer || this.elementRef.nativeElement.parentElement)) === null || _a === void 0 ? void 0 : _a.classList.add('was-validated');
        }
        if ( // prevent creating feedbackElement when it's not yet needed
        !this.feedbackElement
            && this.ngControl.valid) {
            return;
        }
        if (!this.feedbackElement) {
            const feedbackElement = this.createFeedBackElement();
            if (!feedbackElement) {
                return;
            }
            this.feedbackElement = feedbackElement;
            if (this.config.inputGroupFix) {
                this.inputGroupFix();
            }
            this.differ = this.keyValueDiffers.find({}).create();
        }
        if (!((_b = this.differ) === null || _b === void 0 ? void 0 : _b.diff(this.ngControl.errors || {}))) {
            return;
        }
        this.errorMessages.length = 0;
        if (this.ngControl.errors !== null) {
            Object.entries(this.ngControl.errors || {})
                .forEach(([error, errorValue]) => {
                let msg = this.config.errorMessages[error];
                if (typeof this.errorMessage !== 'undefined'
                    && typeof this.errorMessage[error] !== 'undefined') {
                    msg = this.errorMessage[error];
                }
                else if (this.ngControl.control !== null) {
                    const control = this.ngControl.control;
                    if (typeof control.errorMessage !== 'undefined'
                        && typeof control.errorMessage[error] !== 'undefined') {
                        msg = control.errorMessage[error];
                    }
                }
                if (msg) {
                    this.errorMessages.push(msg.replace('%s', this.getErrorValue(error, errorValue)));
                }
            });
        }
        this.feedbackElement.textContent = this.errorMessages.join(',');
    }
    ngOnDestroy() {
        if (this.feedbackElement) {
            this.feedbackElement.remove();
        }
    }
    createFeedBackElement() {
        const parent = this.feedbackElementContainer || this.elementRef.nativeElement.parentNode;
        if (parent) {
            const feedbackElement = this.document.createElement('div');
            feedbackElement.classList.add(`invalid-${this.ngFormValidate.validateMode}`);
            parent.appendChild(feedbackElement);
            return feedbackElement;
        }
        return null;
    }
    inputGroupFix() {
        var _a, _b, _c, _d;
        const parent = this.elementRef.nativeElement.parentElement;
        if (parent) {
            if (parent.classList.contains('input-group')) {
                (_b = (_a = this.feedbackElement) === null || _a === void 0 ? void 0 : _a.previousElementSibling) === null || _b === void 0 ? void 0 : _b.classList.add('rounded-right');
            }
            else {
                (_d = (_c = this.feedbackElement) === null || _c === void 0 ? void 0 : _c.previousElementSibling) === null || _d === void 0 ? void 0 : _d.classList.remove('rounded-right');
            }
        }
    }
    getErrorValue(error, errorValue) {
        if (errorValue === null) {
            return '';
        }
        if (typeof errorValue === 'object') {
            if (error === 'minlength' || error === 'maxlength') {
                return errorValue.requiredLength.toString();
            }
            else if (error === 'pattern') {
                return errorValue.requiredPattern;
            }
            if (error in errorValue) {
                errorValue = errorValue[error];
            }
        }
        switch (typeof errorValue) {
            case 'number':
                return errorValue.toString();
            case 'string':
                return errorValue;
            case 'undefined':
            case 'boolean':
            case 'function':
            case 'symbol':
            default:
                return '';
        }
    }
}
AbstractValidateElementDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: AbstractValidateElementDirective, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
AbstractValidateElementDirective.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: AbstractValidateElementDirective });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: AbstractValidateElementDirective, decorators: [{
            type: Injectable
        }] });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class ValidateConfigService {
    constructor() {
        this.mode = 'feedback';
        this.inputGroupFix = true;
        this.displayOnTouched = false;
        this.errorMessages = {
            required: 'This field is required',
            min: 'Minimum value is %s',
            max: 'Maximum value is %s',
            pattern: 'Please ensure the entered information adheres to this pattern: %s',
            number: 'Please enter a valid number',
            email: 'Please enter a valid e-mail',
            minlength: 'Minimum length of this field is %s characters',
            maxlength: 'Maximum length of this field is %s characters',
            equal: 'These fields needs to be equal',
            url: 'Please enter a valid URL (http(s)://example.com)',
            urlMultiple: 'Please enter valid URLs (http(s)://example.com), each one in new line!',
            host: 'Please enter valid host (example.com)',
            hostMultiple: 'Please enter valid hosts (example.com), each one in new line!',
            requiredGroupOr: 'At least one of these fields is required',
            requiredGroupAnd: 'All of these fields are required',
        };
    }
}
ValidateConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidateConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
ValidateConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidateConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidateConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class NgFormValidateDirective extends AbstractValidateElementDirective {
    constructor(ngForm, formGroup, formGroupName, parent, config, elementRef, keyValueDiffers, document) {
        var _a;
        super();
        this.ngForm = ngForm;
        this.formGroup = formGroup;
        this.formGroupName = formGroupName;
        this.parent = parent;
        this.config = config;
        this.elementRef = elementRef;
        this.keyValueDiffers = keyValueDiffers;
        this.document = document;
        this.ngFormValidate = this;
        this.isGroup = true;
        this.validateMode = config.mode;
        this.wasValidated = elementRef.nativeElement.classList.contains('was-validated');
        this.feedbackElementContainer = this.elementRef.nativeElement;
        this.ngControl = this.ngForm || this.formGroup || this.formGroupName;
        (_a = (this.ngForm || this.formGroup)) === null || _a === void 0 ? void 0 : _a.ngSubmit.subscribe(() => {
            this.showValidation();
        });
    }
    showValidation() {
        this.elementRef.nativeElement.classList.add('was-validated');
        this.wasValidated = true;
    }
    resetValidation() {
        if (this.parent) {
            this.parent.resetValidation();
            return;
        }
        this.children.forEach((child) => {
            var _a;
            const form = child.formGroupName
                ? (_a = child.formGroupName.formDirective) === null || _a === void 0 ? void 0 : _a.getFormGroup(child.formGroupName)
                : (child.ngForm || child.formGroup).form;
            form === null || form === void 0 ? void 0 : form.markAsPristine();
        });
        this.elementRef.nativeElement.querySelectorAll('.was-validated')
            .forEach((node) => {
            node.classList.remove('was-validated');
        });
        this.elementRef.nativeElement.classList.remove('was-validated');
        this.wasValidated = false;
    }
}
NgFormValidateDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: NgFormValidateDirective, deps: [{ token: i1.NgForm, optional: true, self: true }, { token: i1.FormGroupDirective, optional: true, self: true }, { token: i1.FormGroupName, optional: true, self: true }, { token: NgFormValidateDirective, optional: true, skipSelf: true }, { token: ValidateConfigService }, { token: i0.ElementRef }, { token: i0.KeyValueDiffers }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Directive });
NgFormValidateDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: NgFormValidateDirective, selector: "form:not([ngNoForm]),ng-form,[ngForm],[formGroup],[formGroupName]", inputs: { validateMode: "validateMode", errorMessage: "errorMessage" }, providers: [
        {
            provide: VALIDATE_ELEMENT,
            useExisting: NgFormValidateDirective
        }
    ], queries: [{ propertyName: "children", predicate: NgFormValidateDirective, descendants: true }], exportAs: ["ngFormValidate"], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: NgFormValidateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'form:not([ngNoForm]),ng-form,[ngForm],[formGroup],[formGroupName]',
                    exportAs: 'ngFormValidate',
                    providers: [
                        {
                            provide: VALIDATE_ELEMENT,
                            useExisting: NgFormValidateDirective
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i1.NgForm, decorators: [{
                    type: Self
                }, {
                    type: Optional
                }] }, { type: i1.FormGroupDirective, decorators: [{
                    type: Self
                }, {
                    type: Optional
                }] }, { type: i1.FormGroupName, decorators: [{
                    type: Self
                }, {
                    type: Optional
                }] }, { type: NgFormValidateDirective, decorators: [{
                    type: SkipSelf
                }, {
                    type: Optional
                }] }, { type: ValidateConfigService }, { type: i0.ElementRef }, { type: i0.KeyValueDiffers }, { type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; }, propDecorators: { validateMode: [{
                type: Input
            }], errorMessage: [{
                type: Input
            }], children: [{
                type: ContentChildren,
                args: [NgFormValidateDirective, { descendants: true }]
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class NgModelValidateDirective extends AbstractValidateElementDirective {
    // eslint-disable-next-line @typescript-eslint/no-useless-constructor
    constructor(elementRef, config, keyValueDiffers, ngControl, ngFormValidate, document) {
        super();
        this.elementRef = elementRef;
        this.config = config;
        this.keyValueDiffers = keyValueDiffers;
        this.ngControl = ngControl;
        this.ngFormValidate = ngFormValidate;
        this.document = document;
    }
}
NgModelValidateDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: NgModelValidateDirective, deps: [{ token: i0.ElementRef }, { token: ValidateConfigService }, { token: i0.KeyValueDiffers }, { token: i1.NgModel, self: true }, { token: NgFormValidateDirective, optional: true }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Directive });
NgModelValidateDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: NgModelValidateDirective, selector: "[ngModel]", inputs: { errorMessage: "errorMessage" }, providers: [
        {
            provide: VALIDATE_ELEMENT,
            useExisting: NgModelValidateDirective
        }
    ], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: NgModelValidateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngModel]',
                    providers: [
                        {
                            provide: VALIDATE_ELEMENT,
                            useExisting: NgModelValidateDirective
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: ValidateConfigService }, { type: i0.KeyValueDiffers }, { type: i1.NgModel, decorators: [{
                    type: Self
                }] }, { type: NgFormValidateDirective, decorators: [{
                    type: Optional
                }] }, { type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; }, propDecorators: { errorMessage: [{
                type: Input
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class FormControlNameValidateDirective extends AbstractValidateElementDirective {
    // eslint-disable-next-line @typescript-eslint/no-useless-constructor
    constructor(elementRef, config, keyValueDiffers, ngControl, ngFormValidate, document) {
        super();
        this.elementRef = elementRef;
        this.config = config;
        this.keyValueDiffers = keyValueDiffers;
        this.ngControl = ngControl;
        this.ngFormValidate = ngFormValidate;
        this.document = document;
    }
}
FormControlNameValidateDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: FormControlNameValidateDirective, deps: [{ token: i0.ElementRef }, { token: ValidateConfigService }, { token: i0.KeyValueDiffers }, { token: i1.FormControlName, self: true }, { token: NgFormValidateDirective, optional: true }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Directive });
FormControlNameValidateDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: FormControlNameValidateDirective, selector: "[formControlName]", inputs: { errorMessage: "errorMessage" }, providers: [
        {
            provide: VALIDATE_ELEMENT,
            useExisting: FormControlNameValidateDirective
        }
    ], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: FormControlNameValidateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[formControlName]',
                    providers: [
                        {
                            provide: VALIDATE_ELEMENT,
                            useExisting: FormControlNameValidateDirective
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: ValidateConfigService }, { type: i0.KeyValueDiffers }, { type: i1.FormControlName, decorators: [{
                    type: Self
                }] }, { type: NgFormValidateDirective, decorators: [{
                    type: Optional
                }] }, { type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; }, propDecorators: { errorMessage: [{
                type: Input
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class FormControlValidateDirective extends AbstractValidateElementDirective {
    // eslint-disable-next-line @typescript-eslint/no-useless-constructor
    constructor(elementRef, config, keyValueDiffers, ngControl, ngFormValidate, document) {
        super();
        this.elementRef = elementRef;
        this.config = config;
        this.keyValueDiffers = keyValueDiffers;
        this.ngControl = ngControl;
        this.ngFormValidate = ngFormValidate;
        this.document = document;
    }
}
FormControlValidateDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: FormControlValidateDirective, deps: [{ token: i0.ElementRef }, { token: ValidateConfigService }, { token: i0.KeyValueDiffers }, { token: i1.FormControlDirective, self: true }, { token: NgFormValidateDirective, optional: true }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Directive });
FormControlValidateDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: FormControlValidateDirective, selector: "[formControl]", inputs: { errorMessage: "errorMessage" }, providers: [
        {
            provide: VALIDATE_ELEMENT,
            useExisting: FormControlValidateDirective
        }
    ], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: FormControlValidateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[formControl]',
                    providers: [
                        {
                            provide: VALIDATE_ELEMENT,
                            useExisting: FormControlValidateDirective
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: ValidateConfigService }, { type: i0.KeyValueDiffers }, { type: i1.FormControlDirective, decorators: [{
                    type: Self
                }] }, { type: NgFormValidateDirective, decorators: [{
                    type: Optional
                }] }, { type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; }, propDecorators: { errorMessage: [{
                type: Input
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class Validators extends Validators$1 {
    static number(control) {
        if (control.__elementValidity && control.__elementValidity.badInput) {
            return {
                number: true
            };
        }
        return null;
    }
    static url(mode = 'single') {
        return (control) => {
            return validateSingleOrMultiple(mode, control, (value) => /^https?:\/\/.+/.test(value), 'url');
        };
    }
    static host(mode = 'single') {
        return (control) => {
            return validateSingleOrMultiple(mode, control, 
            // eslint-disable-next-line max-len
            (value) => /^([a-z\u00A1-\uFFFF0-9]|[a-z\u00A1-\uFFFF0-9][a-z\u00A1-\uFFFF0-9-]{0,61}[a-z\u00A1-\uFFFF0-9])(\.([a-z\u00A1-\uFFFF0-9]|[a-z\u00A1-\uFFFF0-9][a-z\u00A1-\uFFFF0-9-]{0,61}[a-z\u00A1-\uFFFF0-9]))*$/i.test(value), 'host');
        };
    }
    static equal(...controlNames) {
        return (controlGroup) => {
            const isValid = getControls(controlGroup, controlNames)
                .every((control, idx, controls) => {
                if (idx === 0) {
                    return true;
                }
                const previous = controls[idx - 1];
                return control !== null && previous !== null && control.value === previous.value;
            });
            return isValid ? null : {
                equal: true
            };
        };
    }
    static requiredGroup(mode = 'or', value, ...controlNames) {
        return (controlGroup) => {
            const controls = getControls(controlGroup, controlNames), validateControl = (control) => {
                return typeof value === 'undefined'
                    ? control.value !== null && control.value.length
                    : control.value === value;
            };
            const isValid = mode === 'or'
                ? controls.some(validateControl)
                : controls.every(validateControl);
            return isValid ? null : {
                [`requiredGroup${mode === 'or' ? 'Or' : 'And'}`]: typeof value === 'undefined' ? true : value
            };
        };
    }
}
function validateSingleOrMultiple(mode, control, validator, validatorName) {
    let isValid = true;
    if (typeof control.value === 'string' && control.value.length) {
        if (mode === 'multiple') {
            const rows = control.value.split(/\r\n|\r|\n/);
            isValid = !rows.some((line) => {
                line = line.trim();
                return line.length && !validator(line);
            });
        }
        else {
            isValid = validator(control.value);
        }
    }
    return isValid ? null : {
        [mode === 'single' ? validatorName : `${validatorName}Multiple`]: true
    };
}
function getControls(controlGroup, controlNames) {
    return controlNames.length || !('controls' in controlGroup)
        ? controlNames
            .map((controlName) => controlGroup.get(controlName))
            .filter((x) => x !== null)
        : Object.values(controlGroup.controls);
}

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class NumberValidatorDirective {
    validate(control) {
        return Validators.number(control);
    }
}
NumberValidatorDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: NumberValidatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
NumberValidatorDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: NumberValidatorDirective, selector: "[number]", providers: [
        {
            provide: NG_VALIDATORS,
            useExisting: NumberValidatorDirective,
            multi: true
        }
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: NumberValidatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[number]',
                    providers: [
                        {
                            provide: NG_VALIDATORS,
                            useExisting: NumberValidatorDirective,
                            multi: true
                        }
                    ]
                }]
        }] });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class UrlValidatorDirective {
    validate(control) {
        return Validators.url(this.mode || 'single')(control);
    }
}
UrlValidatorDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: UrlValidatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
UrlValidatorDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: UrlValidatorDirective, selector: "[url]", inputs: { mode: ["url", "mode"] }, providers: [
        {
            provide: NG_VALIDATORS,
            useExisting: UrlValidatorDirective,
            multi: true
        }
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: UrlValidatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[url]',
                    providers: [
                        {
                            provide: NG_VALIDATORS,
                            useExisting: UrlValidatorDirective,
                            multi: true
                        }
                    ]
                }]
        }], propDecorators: { mode: [{
                type: Input,
                args: ['url']
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class HostValidatorDirective {
    validate(control) {
        return Validators.host(this.mode || 'single')(control);
    }
}
HostValidatorDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: HostValidatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
HostValidatorDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: HostValidatorDirective, selector: "[host]", inputs: { mode: ["host", "mode"] }, providers: [
        {
            provide: NG_VALIDATORS,
            useExisting: HostValidatorDirective,
            multi: true
        }
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: HostValidatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[host]',
                    providers: [
                        {
                            provide: NG_VALIDATORS,
                            useExisting: HostValidatorDirective,
                            multi: true
                        }
                    ]
                }]
        }], propDecorators: { mode: [{
                type: Input,
                args: ['host']
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class EqualValidatorDirective {
    constructor() {
        this.controlNames = [];
    }
    validate(control) {
        return Validators.equal(...(this.controlNames || []))(control);
    }
}
EqualValidatorDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: EqualValidatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
EqualValidatorDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: EqualValidatorDirective, selector: "[equal]", inputs: { controlNames: ["equal", "controlNames"] }, providers: [
        {
            provide: NG_VALIDATORS,
            useExisting: EqualValidatorDirective,
            multi: true
        }
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: EqualValidatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[equal]',
                    providers: [
                        {
                            provide: NG_VALIDATORS,
                            useExisting: EqualValidatorDirective,
                            multi: true
                        }
                    ]
                }]
        }], propDecorators: { controlNames: [{
                type: Input,
                args: ['equal']
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class RequiredGroupValidatorDirective {
    validate(controlGroup) {
        const options = typeof this.requiredGroup === 'object' ? this.requiredGroup : {};
        return Validators.requiredGroup(options === null || options === void 0 ? void 0 : options.mode, options === null || options === void 0 ? void 0 : options.value, ...((options === null || options === void 0 ? void 0 : options.controlNames) || []))(controlGroup);
    }
}
RequiredGroupValidatorDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: RequiredGroupValidatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
RequiredGroupValidatorDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.0.5", type: RequiredGroupValidatorDirective, selector: "[requiredGroup]", inputs: { requiredGroup: "requiredGroup" }, providers: [
        {
            provide: NG_VALIDATORS,
            useExisting: RequiredGroupValidatorDirective,
            multi: true
        }
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: RequiredGroupValidatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[requiredGroup]',
                    providers: [
                        {
                            provide: NG_VALIDATORS,
                            useExisting: RequiredGroupValidatorDirective,
                            multi: true
                        }
                    ]
                }]
        }], propDecorators: { requiredGroup: [{
                type: Input
            }] } });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class ValidatorsModule {
}
ValidatorsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidatorsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ValidatorsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidatorsModule, declarations: [EqualValidatorDirective,
        HostValidatorDirective,
        NumberValidatorDirective,
        RequiredGroupValidatorDirective,
        UrlValidatorDirective], exports: [EqualValidatorDirective,
        HostValidatorDirective,
        NumberValidatorDirective,
        RequiredGroupValidatorDirective,
        UrlValidatorDirective] });
ValidatorsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidatorsModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidatorsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        EqualValidatorDirective,
                        HostValidatorDirective,
                        NumberValidatorDirective,
                        RequiredGroupValidatorDirective,
                        UrlValidatorDirective,
                    ],
                    exports: [
                        EqualValidatorDirective,
                        HostValidatorDirective,
                        NumberValidatorDirective,
                        RequiredGroupValidatorDirective,
                        UrlValidatorDirective,
                    ]
                }]
        }] });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */
class ValidateModule {
}
ValidateModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidateModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ValidateModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidateModule, declarations: [FormControlNameValidateDirective,
        FormControlValidateDirective,
        NgFormValidateDirective,
        NgModelValidateDirective], imports: [ValidatorsModule], exports: [FormControlNameValidateDirective,
        FormControlValidateDirective,
        NgFormValidateDirective,
        NgModelValidateDirective,
        ValidatorsModule] });
ValidateModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidateModule, imports: [[
            ValidatorsModule
        ], ValidatorsModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.5", ngImport: i0, type: ValidateModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        FormControlNameValidateDirective,
                        FormControlValidateDirective,
                        NgFormValidateDirective,
                        NgModelValidateDirective
                    ],
                    imports: [
                        ValidatorsModule
                    ],
                    exports: [
                        FormControlNameValidateDirective,
                        FormControlValidateDirective,
                        NgFormValidateDirective,
                        NgModelValidateDirective,
                        ValidatorsModule
                    ]
                }]
        }] });

/*
 * Angular validation plugin for  Bootstrap 4
 *  Copyright (c) 2019-2021 Rodziu <mateusz.rohde@gmail.com>
 *  License: MIT
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AbstractValidateElementDirective, EqualValidatorDirective, FormControlNameValidateDirective, FormControlValidateDirective, HostValidatorDirective, NgFormValidateDirective, NgModelValidateDirective, NumberValidatorDirective, RequiredGroupValidatorDirective, UrlValidatorDirective, VALIDATE_ELEMENT, ValidateConfigService, ValidateModule, Validators, ValidatorsModule };
//# sourceMappingURL=angular-bootstrap4-validate.js.map
